@@ -12,7 +12,7 @@ use File::BaseDir qw(config_home data_home);
 use File::Path qw(make_path);
 use File::Slurp qw(slurp write_file);
 
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 
 sub new {
 	my ( $class, %opt ) = @_;
@@ -47,7 +47,7 @@ sub file_to_hash {
 	my $ret;
 
 	for my $line ( slurp($file) ) {
-		my ( $key, $value ) = split( qr{ \s+ }x, $line );
+		my ( $key, $value ) = ( $line =~ m{ ^ ([^ ]+) \s+ (.+) $ }x );
 
 		if ( not( $key and $value ) ) {
 			next;
@@ -302,7 +302,7 @@ B<App::Raps2> is the backend for B<raps2>, a simple commandline password safe.
 
 =head1 VERSION
 
-This manual documents App::Raps2 version 0.53
+This manual documents App::Raps2 version 0.54
 
 =head1 METHODS
 
@@ -461,7 +461,7 @@ documentation may not be completely up-to-date.
 
 =head1 AUTHOR
 
-Copyright (C) 2011 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2011-2015 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
