@@ -8,15 +8,13 @@ use Carp qw(cluck confess);
 use POSIX;
 use Term::ReadLine;
 
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 
 sub new {
 	my ($obj) = @_;
 
 	my $ref = {};
 
-	$ref->{term_readline} = Term::ReadLine->new('App::Raps2');
-
 	return bless( $ref, $obj );
 }
 
@@ -37,6 +35,12 @@ sub list {
 sub read_line {
 	my ( $self, $str, $pre ) = @_;
 
+	# Term::ReadLine->new() takes quite long but is not always required.
+	# So create it here (if needed) instead of in ->new
+	if ( not $self->{term_readline} ) {
+		$self->{term_readline} = Term::ReadLine->new('App::Raps2');
+	}
+
 	my $input = $self->{term_readline}->readline( "${str}: ", $pre );
 
 	return $input;
@@ -134,7 +138,7 @@ App::Raps2::UI - App::Raps2 User Interface
 
 =head1 VERSION
 
-This manual documents B<App::Raps2::UI> version 0.53
+This manual documents B<App::Raps2::UI> version 0.54
 
 =head1 DESCRIPTION
 
@@ -208,7 +212,7 @@ App::Raps2(3pm).
 
 =head1 AUTHOR
 
-Copyright (C) 2011 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2011-2015 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
